@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** No Commercial Usage
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in 
+** accordance with the Qt Commercial License Agreement provided with
+** the Software or, alternatively, in accordance with the terms
+** contained in a written agreement between you and Nokia.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**
-**
-**
-**
-**
-**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -66,7 +66,6 @@ QTM_BEGIN_NAMESPACE
     interactions between the user and the map.
 
     \inmodule QtLocation
-    \since 1.1
 
     \ingroup maps-mapping
 
@@ -159,14 +158,6 @@ QGraphicsGeoMap::QGraphicsGeoMap(QGeoMappingManager *manager, QGraphicsItem *par
             SIGNAL(zoomLevelChanged(qreal)),
             this,
             SIGNAL(zoomLevelChanged(qreal)));
-    connect(d_ptr->mapData,
-            SIGNAL(bearingChanged(qreal)),
-            this,
-            SIGNAL(bearingChanged(qreal)));
-    connect(d_ptr->mapData,
-            SIGNAL(tiltChanged(qreal)),
-            this,
-            SIGNAL(tiltChanged(qreal)));
     connect(d_ptr->mapData,
             SIGNAL(mapTypeChanged(QGraphicsGeoMap::MapType)),
             this,
@@ -197,7 +188,6 @@ QGraphicsGeoMap::~QGraphicsGeoMap()
 
 /*!
   \reimp
-  \since 1.1
 */
 void QGraphicsGeoMap::resizeEvent(QGraphicsSceneResizeEvent *event)
 {
@@ -208,7 +198,6 @@ void QGraphicsGeoMap::resizeEvent(QGraphicsSceneResizeEvent *event)
 
 /*!
   \reimp
-  \since 1.1
 */
 QPainterPath QGraphicsGeoMap::shape() const
 {
@@ -219,7 +208,6 @@ QPainterPath QGraphicsGeoMap::shape() const
 
 /*!
   \reimp
-  \since 1.1
 */
 void QGraphicsGeoMap::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *)
 {
@@ -239,7 +227,6 @@ void QGraphicsGeoMap::updateMapDisplay(const QRectF &target)
 
     Larger values of the zoom level correspond to more detailed views of the
     map.
-    \since 1.1
 */
 qreal QGraphicsGeoMap::minimumZoomLevel() const
 {
@@ -256,7 +243,6 @@ qreal QGraphicsGeoMap::minimumZoomLevel() const
 
     Larger values of the zoom level correspond to more detailed views of the
     map.
-    \since 1.1
 */
 qreal QGraphicsGeoMap::maximumZoomLevel() const
 {
@@ -276,7 +262,6 @@ qreal QGraphicsGeoMap::maximumZoomLevel() const
     If zoomLevel is less than minimumZoomLevel then minimumZoomLevel
     will be used, and if zoomLevel is  larger than
     maximumZoomLevel then maximumZoomLevel will be used.
-    \since 1.1
 */
 void QGraphicsGeoMap::setZoomLevel(qreal zoomLevel)
 {
@@ -291,121 +276,6 @@ qreal QGraphicsGeoMap::zoomLevel() const
 
     return -1;
 }
-/*!
-    \property QGraphicsGeoMap::supportsBearing
-    \brief This property holds whether bearing is supported by the
-    QGeoMappingManager associated with this widget.
-    \since 1.2
-*/
-bool QGraphicsGeoMap::supportsBearing() const
-{
-    if (d_ptr->mapData)
-        return d_ptr->mapData->supportsBearing();
-
-    return false;
-}
-
-/*!
-    \property QGraphicsGeoMap::bearing
-    \brief This property holds the bearing of the map.
-
-    Value in degrees where 0 is equivalent to 90 degrees between view and earth's
-    surface i.e. looking straight down to earth.
-
-    Changes to this property will be ignored if supportsBearing()
-    returns false.
-    \since 1.2
-*/
-void QGraphicsGeoMap::setBearing(qreal bearing)
-{
-    if (d_ptr->mapData)
-        d_ptr->mapData->setBearing(bearing);
-}
-
-qreal QGraphicsGeoMap::bearing() const
-{
-    if (d_ptr->mapData)
-        return d_ptr->mapData->bearing();
-
-    return 0;
-}
-
-/*!
-    \property QGraphicsGeoMap::supportsTilting
-    \brief This property holds whether tilting is supported by the
-    QGeoMappingManager associated with this widget.
-    \since 1.2
-*/
-bool QGraphicsGeoMap::supportsTilting() const
-{
-    if (d_ptr->mapData)
-        return d_ptr->mapData->supportsTilting();
-
-    return false;
-}
-
-/*!
-    \property QGraphicsGeoMap::minimumTilt
-    \brief This property holds the minimum tilt supported by the
-    QGeoMappingManager associated with this widget.
-
-    Value in degrees where 0 is equivalent to 90 degrees between view and earth's
-    surface i.e. looking straight down to earth.
-    \since 1.2
-*/
-qreal QGraphicsGeoMap::minimumTilt() const
-{
-    if (d_ptr->mapData)
-        return d_ptr->mapData->minimumTilt();
-
-    return 0;
-}
-
-/*!
-    \property QGraphicsGeoMap::maximumTilt
-    \brief This property holds the maximum tilt supported by the
-    QGeoMappingManager associated with this widget.
-
-    Value in degrees where 0 is equivalent to 90 degrees between view and earth's
-    surface i.e. looking straight down to earth.
-    \since 1.2
-*/
-qreal QGraphicsGeoMap::maximumTilt() const
-{
-    if (d_ptr->mapData)
-        return d_ptr->mapData->maximumTilt();
-
-    return 0;
-}
-
-/*!
-    \property QGraphicsGeoMap::tilt
-    \brief This property holds the tilt of the map.
-
-    Value in degrees where 0 is equivalent to 90 degrees between view and earth's
-    surface i.e. looking straight down to earth.
-
-    If \a tilt is less than minimumTilt() then minimumTilt()
-    will be used, and if \a tilt is  larger than
-    maximumTilt() then maximumTilt() will be used.
-
-    Changes to this property will be ignored if supportsTilting()
-    returns false.
-    \since 1.2
-*/
-void QGraphicsGeoMap::setTilt(qreal tilt)
-{
-    if (d_ptr->mapData)
-        d_ptr->mapData->setTilt(tilt);
-}
-
-qreal QGraphicsGeoMap::tilt() const
-{
-    if (d_ptr->mapData)
-        return d_ptr->mapData->tilt();
-
-    return 0;
-}
 
 /*!
     Pans the map view \a dx pixels in the x direction and \a dy pixels
@@ -417,7 +287,6 @@ qreal QGraphicsGeoMap::tilt() const
     viewed area down.
 
     After the panning has occurred the centerChanged() signal will be emitted.
-    \since 1.1
 */
 void QGraphicsGeoMap::pan(int dx, int dy)
 {
@@ -433,7 +302,6 @@ void QGraphicsGeoMap::pan(int dx, int dy)
 
     Panning the map can be more efficient than changing the center by small
     increments.
-    \since 1.1
 */
 void QGraphicsGeoMap::setCenter(const QGeoCoordinate &center)
 {
@@ -452,7 +320,6 @@ QGeoCoordinate QGraphicsGeoMap::center() const
 /*!
     Returns the map types supported by the QGeoMappingManager associated with
     this widget.
-    \since 1.1
 */
 QList<QGraphicsGeoMap::MapType> QGraphicsGeoMap::supportedMapTypes() const
 {
@@ -468,7 +335,6 @@ QList<QGraphicsGeoMap::MapType> QGraphicsGeoMap::supportedMapTypes() const
 
   Setting mapType to a type not present in supportedMapTypes() will do
   nothing.
-    \since 1.1
 */
 void QGraphicsGeoMap::setMapType(QGraphicsGeoMap::MapType mapType)
 {
@@ -491,7 +357,6 @@ QGraphicsGeoMap::MapType QGraphicsGeoMap::mapType() const
 /*!
     Returns the connectivity modes supported by the QGeoMappingManager associated with
     this widget.
-    \since 1.1
 */
 QList<QGraphicsGeoMap::ConnectivityMode> QGraphicsGeoMap::supportedConnectivityModes() const
 {
@@ -507,7 +372,6 @@ QList<QGraphicsGeoMap::ConnectivityMode> QGraphicsGeoMap::supportedConnectivityM
 
   Setting connectivityMode to a mode not present in supportedConnectivityModes() will do
   nothing.
-  \since 1.1
 */
 void QGraphicsGeoMap::setConnectivityMode(QGraphicsGeoMap::ConnectivityMode connectivityMode)
 {
@@ -527,25 +391,8 @@ QGraphicsGeoMap::ConnectivityMode QGraphicsGeoMap::connectivityMode() const
     return QGraphicsGeoMap::NoConnectivity;
 }
 
-/*!
-    Returns whether custom map objects are supported by this engine.
-
-    Custom map objects are map objects based on QGraphicsItem instances, which
-    are hard to support in cases where the map rendering is not being
-    performed by the Qt Graphics View framwork.
-    \since 1.2
-*/
-bool QGraphicsGeoMap::supportsCustomMapObjects() const
-{
-    if (d_ptr->manager)
-        return d_ptr->manager->supportsCustomMapObjects();
-
-    return false;
-}
-
 /*!
     Returns the map objects associated with this map.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGraphicsGeoMap::mapObjects() const
 {
@@ -563,19 +410,12 @@ QList<QGeoMapObject*> QGraphicsGeoMap::mapObjects() const
     object immediately.
 
     The map will take ownership of the \a mapObject.
-
-    If supportsCustomMapObject() returns false and \a mapObject is a custom map
-    object then \a mapObject will not be added to the map.
-    \since 1.1
 */
 void QGraphicsGeoMap::addMapObject(QGeoMapObject *mapObject)
 {
     if (!mapObject || !d_ptr->mapData)
         return;
 
-    if ((mapObject->type() == QGeoMapObject::CustomType) && !supportsCustomMapObjects())
-        return;
-
     d_ptr->mapData->addMapObject(mapObject);
 
     this->update();
@@ -589,7 +429,6 @@ void QGraphicsGeoMap::addMapObject(QGeoMapObject *mapObject)
     the map object immediately.
 
     The map will release ownership of the \a mapObject.
-    \since 1.1
 */
 void QGraphicsGeoMap::removeMapObject(QGeoMapObject *mapObject)
 {
@@ -605,7 +444,6 @@ void QGraphicsGeoMap::removeMapObject(QGeoMapObject *mapObject)
     Clears the map objects associated with this map.
 
     The map objects will be deleted.
-    \since 1.1
 */
 void QGraphicsGeoMap::clearMapObjects()
 {
@@ -617,7 +455,6 @@ void QGraphicsGeoMap::clearMapObjects()
 
 /*!
     Returns the map overlays associated with this map.
-    \since 1.1
 */
 QList<QGeoMapOverlay*> QGraphicsGeoMap::mapOverlays() const
 {
@@ -633,7 +470,6 @@ QList<QGeoMapOverlay*> QGraphicsGeoMap::mapOverlays() const
     The overlays will be drawn in the order in which they were added.
 
     The map will take ownership of \a overlay.
-    \since 1.1
 */
 void QGraphicsGeoMap::addMapOverlay(QGeoMapOverlay *overlay)
 {
@@ -649,7 +485,6 @@ void QGraphicsGeoMap::addMapOverlay(QGeoMapOverlay *overlay)
     Removes \a overlay from the list of map overlays associated with this map.
 
     The map will release ownership of \a overlay.
-    \since 1.1
 */
 void QGraphicsGeoMap::removeMapOverlay(QGeoMapOverlay *overlay)
 {
@@ -665,7 +500,6 @@ void QGraphicsGeoMap::removeMapOverlay(QGeoMapOverlay *overlay)
     Clears the map overlays associated with this map.
 
     The map overlays will be deleted.
-    \since 1.1
 */
 void QGraphicsGeoMap::clearMapOverlays()
 {
@@ -681,7 +515,6 @@ void QGraphicsGeoMap::clearMapOverlays()
 
     The bounding box which is returned is defined by the upper left and
     lower right corners of the visible area of the map.
-    \since 1.1
 */
 QGeoBoundingBox QGraphicsGeoMap::viewport() const
 {
@@ -700,7 +533,6 @@ QGeoBoundingBox QGraphicsGeoMap::viewport() const
     If \a preserveViewportCenter is false the map will be centered on the
     bounding box \a bounds before the zoom level is changed, otherwise the
     center of the map will not be changed.
-    \since 1.1
 */
 void QGraphicsGeoMap::fitInViewport(const QGeoBoundingBox &bounds, bool preserveViewportCenter)
 {
@@ -713,7 +545,6 @@ void QGraphicsGeoMap::fitInViewport(const QGeoBoundingBox &bounds, bool preserve
 /*!
     Returns the list of visible map objects managed by this widget which
     contain the point \a screenPosition within their boundaries.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGraphicsGeoMap::mapObjectsAtScreenPosition(const QPointF &screenPosition) const
 {
@@ -727,7 +558,6 @@ QList<QGeoMapObject*> QGraphicsGeoMap::mapObjectsAtScreenPosition(const QPointF
     Returns the list of visible map objects managed by this widget which are
     displayed at least partially within the on screen rectangle
     \a screenRect.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGraphicsGeoMap::mapObjectsInScreenRect(const QRectF &screenRect) const
 {
@@ -740,7 +570,6 @@ QList<QGeoMapObject*> QGraphicsGeoMap::mapObjectsInScreenRect(const QRectF &scre
 /*!
     Returns the list of visible map objects manager by this widget which
     are displayed at least partially within the viewport of the map.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGraphicsGeoMap::mapObjectsInViewport() const
 {
@@ -755,7 +584,6 @@ QList<QGeoMapObject*> QGraphicsGeoMap::mapObjectsInViewport() const
 
     An invalid QPointF will be returned if \a coordinate is invalid or is not
     within the current viewport.
-    \since 1.1
 */
 QPointF QGraphicsGeoMap::coordinateToScreenPosition(const QGeoCoordinate &coordinate) const
 {
@@ -771,7 +599,6 @@ QPointF QGraphicsGeoMap::coordinateToScreenPosition(const QGeoCoordinate &coordi
 
     An invalid QGeoCoordinate will be returned if \a screenPosition is invalid
     or is not within the current viewport.
-    \since 1.1
 */
 QGeoCoordinate QGraphicsGeoMap::screenPositionToCoordinate(QPointF screenPosition) const
 {
@@ -787,31 +614,6 @@ QGeoCoordinate QGraphicsGeoMap::screenPositionToCoordinate(QPointF screenPositio
     This signal is emitted when the zoom level of the map changes.
 
     The new value is \a zoomLevel.
-    \since 1.1
-*/
-
-/*!
-\fn void QGraphicsGeoMap::bearingChanged(qreal bearing)
-
-    This signal is emitted when the bearing of the map changes.
-
-    The new value is \a bearing.
-
-    This signal will not be emitted if supportsBearing()
-    returns false.
-    \since 1.2
-*/
-
-/*!
-\fn void QGraphicsGeoMap::tiltChanged(qreal tilt)
-
-    This signal is emitted when the tilt of the map changes.
-
-    The new value is \a tilt.
-
-    This signal will not be emitted if supportsTilting()
-    returns false.
-    \since 1.2
 */
 
 /*!
@@ -820,7 +622,6 @@ QGeoCoordinate QGraphicsGeoMap::screenPositionToCoordinate(QPointF screenPositio
     This signal is emitted when the center of the map changes.
 
     The new value is \a coordinate.
-    \since 1.1
 */
 
 /*!
@@ -829,17 +630,15 @@ QGeoCoordinate QGraphicsGeoMap::screenPositionToCoordinate(QPointF screenPositio
     This signal is emitted when the map type changes.
 
     The new value is \a mapType.
-    \since 1.1
 */
 
 /*!
 \fn void QGraphicsGeoMap::connectivityModeChanged(QGraphicsGeoMap::ConnectivityMode connectivityMode)
 
-    This signal is emitted when the connectivity mode used to fetch the
+    This signal is emitted when the connectivity mode used to fetch the 
     map data changes.
 
     The new value is \a connectivityMode.
-    \since 1.1
 */
 
 /*******************************************************************************
