@@ -55,14 +55,15 @@ QTM_BEGIN_NAMESPACE
 
 // constructor
 CQGeoSatelliteInfoSourceS60::CQGeoSatelliteInfoSourceS60(QObject* aParent) : QGeoSatelliteInfoSource(aParent),
-    mCurrentModuleId(TUid::Null()),
-    mReqModuleId(TUid::Null()),
-    mDevStatusUpdateAO(NULL),
-    mReqUpdateAO(NULL),
-    mRegUpdateAO(NULL),
-    mListSize(0),
-    mStartUpdates(FALSE),
-    mModuleFlags(0)
+        mCurrentModuleId(TUid::Null()),
+        mReqModuleId(TUid::Null()),
+        mDevStatusUpdateAO(NULL),
+        mReqUpdateAO(NULL),
+        mRegUpdateAO(NULL),
+        mListSize(0),
+        mMinUpdateInterval(0),
+        mStartUpdates(FALSE),
+        mModuleFlags(0)
 {
     memset(mList, 0 , MAX_SIZE * sizeof(CSatMethodInfo));
 }
@@ -149,8 +150,8 @@ void CQGeoSatelliteInfoSourceS60::ConstructL()
             index = getIndexPositionModule(bits);
 
             if (index >= 0) {
-                TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                      mList[index].mUid));
+                TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                      mList[index].mUid)));
 
                 if ((ret == KErrNone) && (temp != NULL))
                     break;
@@ -173,8 +174,9 @@ void CQGeoSatelliteInfoSourceS60::ConstructL()
 }
 
 //private function : to retrieve the index of the supplied module id from the mList array
-TInt CQGeoSatelliteInfoSourceS60::checkModule(TPositionModuleId aId)const
+TInt CQGeoSatelliteInfoSourceS60::checkModule(TPositionModuleId aId)//const
 {
+    QMutexLocker locker(&m_mutex);
     TInt i;
     for (i = 0; i < mListSize; i++)
         if (mList[i].mUid == aId)
@@ -188,10 +190,12 @@ int CQGeoSatelliteInfoSourceS60::minimumUpdateInterval() const
     if (mCurrentModuleId == TUid::Null())
         return 0;
 
-    TInt i = checkModule(mCurrentModuleId);
+    return mMinUpdateInterval;
+
+    /*TInt i = checkModule(mCurrentModuleId);
     if (i != -1)
         return mList[i].mTimeToNextFix.Int64() / 1000;           //divide by 1000, to convert microsecond to milisecond
-    return 0;
+    return 0;*/
 }
 
 //private function : get the index of the mList that supports the preferred method if
@@ -301,6 +305,7 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
 
     if ((i = checkModule(id)) == -1) {
         //update the properties of the module
+        QMutexLocker lLocker(&m_mutex);
 
         //TPositionModuleId of the module
         mList[mListSize].mUid = id;
@@ -322,7 +327,13 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
 
         //count on the mList array size
         mListSize++;
+
+        mMinUpdateInterval = mList[mListSize-1].mTimeToNextFix.Int64() / 1000;
+        lLocker.unlock();
     } else {
+
+        QMutexLocker lLocker(&m_mutex);
+
         //module's status has changed
         if (mList[i].mStatus != aStatus)
             mList[i].mStatus = aStatus;
@@ -343,6 +354,8 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
         if (mList[i].mTimeToNextFix != time_to_next_fix)
             mList[i].mTimeToFirstFix = time_to_next_fix;
 
+        lLocker.unlock();
+
         //if the mCurrentModuleId is NULL, try updating the reg update with the available
         //positioning method
         if (mCurrentModuleId == TUid::Null() && (available == TRUE) &&
@@ -350,12 +363,13 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
                 (aStatus != TPositionModuleStatus::EDeviceError)) {
             TInt interval = 0;
 
-            TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                  mList[i].mUid));
+            TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                  mList[i].mUid)));
 
             if ((ret == KErrNone) && (temp != NULL)) {
                 temp->setUpdateInterval(interval);
 
+                QMutexLocker lRegLocker(&m_mutex_RegUpAO);
                 if (mRegUpdateAO)
                     delete mRegUpdateAO;
                 mRegUpdateAO = temp;
@@ -367,6 +381,8 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
 
 
                 mCurrentModuleId = mList[i].mUid;
+                mMinUpdateInterval = mList[i].mTimeToNextFix.Int64() / 1000;
+                lRegLocker.unlock();
 
             }
         }
@@ -383,8 +399,10 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
 
                 TUint8 bits;
 
+                QMutexLocker lRegLocker1(&m_mutex_RegUpAO);
                 if (mRegUpdateAO)
                     delete  mRegUpdateAO;
+                lRegLocker1.unlock();
 
                 bits = mModuleFlags;
 
@@ -394,8 +412,8 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
                     index = getIndexPositionModule(bits);
 
                     if (index >= 0) {
-                        TRAPD(ret, temp = CQMLBackendAO::NewL(this, RegularUpdate,
-                                                              mList[index].mUid));
+                        TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, RegularUpdate,
+                                                              mList[index].mUid)));
 
                         if ((ret == KErrNone) && (temp != NULL))
                             break;
@@ -408,30 +426,37 @@ void CQGeoSatelliteInfoSourceS60::updateStatus(TPositionModuleInfo &aModInfo, TI
                 if (temp != NULL) {
                     //successful in creating the subsession for the required
                     //method
+                    QMutexLocker lRegLocker2(&m_mutex_RegUpAO);
                     mRegUpdateAO = temp;
 
+                    mCurrentModuleId = mList[index].mUid;
+                    mMinUpdateInterval = mList[i].mTimeToNextFix.Int64() / 1000;
+                    lRegLocker2.unlock();
+
                     mRegUpdateAO->setUpdateInterval(interval);
 
                     if (mStartUpdates)
                         mRegUpdateAO->startUpdates();
 
-
-                    mCurrentModuleId = mList[index].mUid;
-
                 } else {
                     //no methods available,clean up the resources
+                    QMutexLocker lRegLocker3(&m_mutex_RegUpAO);
                     mRegUpdateAO = NULL;
                     mCurrentModuleId = TUid::Null();
+                    mMinUpdateInterval = interval;
+                    lRegLocker3.unlock();
                 }
 
             }
 
             //check if device status of the request update module changed
             if (id == mReqModuleId) {
+                QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
                 if (mRegUpdateAO)
                     delete mReqUpdateAO;
                 mReqUpdateAO = NULL;
                 mReqModuleId = TUid::Null();
+                lReqLocker.unlock();
                 emit requestTimeout();
             }
 
@@ -593,9 +618,11 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
             }
         }
 
-        TRAPD(ret, temp = CQMLBackendAO::NewL(this, OnceUpdate, mList[index].mUid));
+        TRAPD(ret, QT_TRYCATCH_LEAVING(temp = CQMLBackendAO::NewL(this, OnceUpdate, mList[index].mUid)));
 
         if ((ret == KErrNone) && (temp != NULL)) {
+
+            QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
             //delete the old reqest update
             if (mReqUpdateAO)
                 delete mReqUpdateAO;
@@ -605,6 +632,7 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
 
             //set the request module ID
             mReqModuleId = mList[index].mUid;
+            lReqLocker.unlock();
 
             //start the update
             mReqUpdateAO->requestUpdate(aTimeout);
@@ -618,8 +646,10 @@ void CQGeoSatelliteInfoSourceS60::requestUpdate(int aTimeout)
 
     //cleanup resources if the invalid requpdate is still stored
     if (mReqUpdateAO) {
+        QMutexLocker lReqLocker(&m_mutex_ReqUpAO);
         delete mReqUpdateAO;
         mReqUpdateAO = NULL;
+        lReqLocker.unlock();
         mReqModuleId = TUid::Null();
     }
 
